@@ -1,6 +1,7 @@
 # -*- coding: utf-8 -*-
 #
 # Copyright 2014 - Mirantis, Inc.
+# Copyright 2014 - StackStorm, Inc.
 #
 #    Licensed under the Apache License, Version 2.0 (the "License");
 #    you may not use this file except in compliance with the License.
@@ -85,13 +86,18 @@ class HTTPAction(base.Action):
                  timeout=None,
                  allow_redirects=None,
                  proxies=None):
+
+        if auth and len(auth.split(':')) == 2:
+            self.auth = (auth.split(':')[0], auth.split(':')[1])
+        else:
+            self.auth = auth
+
         self.url = url
         self.method = method
         self.params = params
         self.body = json.dumps(body) if isinstance(body, dict) else body
         self.headers = headers
         self.cookies = cookies
-        self.auth = auth
         self.timeout = timeout
         self.allow_redirects = allow_redirects
         self.proxies = proxies
@@ -164,9 +170,9 @@ class MistralHTTPAction(HTTPAction):
                  proxies=None):
         headers = headers or {}
         headers.update({
-            'Mistral-Workbook-Name': action_context['workbook_name'],
-            'Mistral-Execution-Id': action_context['execution_id'],
-            'Mistral-Task-Id': action_context['task_id'],
+            'Mistral-Workflow-Name': action_context.get('workflow_name'),
+            'Mistral-Execution-Id': action_context.get('execution_id'),
+            'Mistral-Task-Id': action_context.get('task_id'),
         })
 
         super(MistralHTTPAction, self).__init__(
