@@ -33,10 +33,13 @@ class Workflow(resource.Resource):
 
     id = wtypes.text
     name = wtypes.text
+    input = wtypes.text
 
     definition = wtypes.text
+    "Workflow definition in Mistral v2 DSL"
     tags = [wtypes.text]
     scope = SCOPE_TYPES
+    "'private' or 'public'"
 
     created_at = wtypes.text
     updated_at = wtypes.text
@@ -45,12 +48,27 @@ class Workflow(resource.Resource):
     def sample(cls):
         return cls(id='123e4567-e89b-12d3-a456-426655440000',
                    name='flow',
-                   definition='---',
+                   input='param1, param2',
+                   definition='HERE GOES'
+                        'WORKFLOW DEFINITION IN MISTRAL DSL v2',
                    tags=['large', 'expensive'],
                    scope='private',
                    created_at='1970-01-01T00:00:00.000000',
                    updated_at='1970-01-01T00:00:00.000000')
 
+    @classmethod
+    def from_dict(cls, d):
+        e = cls()
+
+        for key, val in d.items():
+            if hasattr(e, key):
+                setattr(e, key, val)
+
+        input = d['spec'].get('input')
+        setattr(e, 'input', ", ".join(input) if input else None)
+
+        return e
+
 
 class Workflows(resource.Resource):
     """A collection of workflows."""
