@@ -12,21 +12,20 @@
 #    See the License for the specific language governing permissions and
 #    limitations under the License.
 
-from pecan.hooks import PecanHook
+from pecan import hooks
 
 from mistral import engine
-from mistral.engine import client
 from mistral.openstack.common import log as logging
 
 
 LOG = logging.getLogger(__name__)
 
 
-class EngineHook(PecanHook):
+class EngineHook(hooks.PecanHook):
 
     def __init__(self, transport=None):
         self.transport = engine.get_transport(transport)
-        self.engine = client.EngineClient(self.transport)
+        self.engine = engine.EngineClient(self.transport)
 
     def before(self, state):
         state.request.context['engine'] = self.engine
