@@ -23,24 +23,19 @@ from oslo.config import cfg
 from mistral.openstack.common import log
 from mistral import version
 
+launch_opt = cfg.ListOpt(
+    'server',
+    default=['all'],
+    help='Specifies which mistral server to start by the launch script. '
+         'Valid options are all or any combination of '
+         'api, engine, and executor.'
+)
+
 api_opts = [
     cfg.StrOpt('host', default='0.0.0.0', help='Mistral API server host'),
     cfg.IntOpt('port', default=8989, help='Mistral API server port')
 ]
 
-engine_opts = [
-    cfg.StrOpt('engine', default='default',
-               help='Mistral engine plugin'),
-    cfg.StrOpt('host', default='0.0.0.0',
-               help='Name of the engine node. This can be an opaque '
-                    'identifier. It is not necessarily a hostname, '
-                    'FQDN, or IP address.'),
-    cfg.StrOpt('topic', default='engine',
-               help='The message topic that the engine listens on.'),
-    cfg.StrOpt('version', default='1.0',
-               help='The version of the engine.')
-]
-
 pecan_opts = [
     cfg.StrOpt('root', default='mistral.api.controllers.root.RootController',
                help='Pecan root controller'),
@@ -68,6 +63,19 @@ use_debugger = cfg.BoolOpt(
     'Use at your own risk.'
 )
 
+engine_opts = [
+    cfg.StrOpt('engine', default='default',
+               help='Mistral engine plugin'),
+    cfg.StrOpt('host', default='0.0.0.0',
+               help='Name of the engine node. This can be an opaque '
+                    'identifier. It is not necessarily a hostname, '
+                    'FQDN, or IP address.'),
+    cfg.StrOpt('topic', default='engine',
+               help='The message topic that the engine listens on.'),
+    cfg.StrOpt('version', default='1.0',
+               help='The version of the engine.')
+]
+
 executor_opts = [
     cfg.StrOpt('host', default='0.0.0.0',
                help='Name of the executor node. This can be an opaque '
@@ -79,20 +87,6 @@ executor_opts = [
                help='The version of the executor.')
 ]
 
-launch_opt = cfg.ListOpt(
-    'server',
-    default=['all'],
-    help='Specifies which mistral server to start by the launch script. '
-         'Valid options are all or any combination of '
-         'api, engine, and executor.'
-)
-
-action_plugins_opt = cfg.ListOpt(
-    'action_plugins',
-    default=['mistral.actions.std'],
-    help='List of namespaces to search for plug-ins.')
-
-
 wf_trace_log_name_opt = cfg.StrOpt('workflow_trace_log_name',
                                    default='workflow_trace',
                                    help='Logger name for pretty '
@@ -106,7 +100,6 @@ CONF.register_opts(pecan_opts, group='pecan')
 CONF.register_opts(db_opts, group='database')
 CONF.register_opts(executor_opts, group='executor')
 CONF.register_opt(wf_trace_log_name_opt)
-CONF.register_opt(action_plugins_opt)
 
 CONF.register_cli_opt(use_debugger)
 CONF.register_cli_opt(launch_opt)
