@@ -148,7 +148,8 @@ class Action(mb.MistralModelBase):
     id = mb.id_column()
     name = sa.Column(sa.String(200))
     description = sa.Column(sa.Text())
-    input = sa.Column(sa.String(240))
+    tags = sa.Column(st.JsonListType())
+    input = sa.Column(sa.Text())
 
     # Ad-hoc action properties.
     definition = sa.Column(sa.Text(), nullable=True)
@@ -163,3 +164,36 @@ class Action(mb.MistralModelBase):
     scope = sa.Column(sa.String(80))
     project_id = sa.Column(sa.String(80))
     trust_id = sa.Column(sa.String(80))
+
+
+class CronTrigger(mb.MistralModelBase):
+    """Contains info about cron triggers."""
+
+    __tablename__ = 'cron_triggers_v2'
+
+    __table_args__ = (
+        sa.UniqueConstraint('name', 'project_id'),
+    )
+
+    id = mb.id_column()
+    name = sa.Column(sa.String(200))
+    pattern = sa.Column(sa.String(100))
+    next_execution_time = sa.Column(sa.DateTime, nullable=False)
+    workflow_name = sa.Column(sa.String(80))
+
+    workflow_id = sa.Column(sa.String(36), sa.ForeignKey('workflows_v2.id'))
+    workflow = relationship('Workflow', lazy='joined')
+
+    workflow_input = sa.Column(st.JsonDictType())
+
+    # Security properties.
+    scope = sa.Column(sa.String(80))
+    project_id = sa.Column(sa.String(80))
+    trust_id = sa.Column(sa.String(80))
+
+    def to_dict(self):
+        d = super(CronTrigger, self).to_dict()
+
+        mb.datetime_to_str(d, 'next_execution_time')
+
+        return d
