@@ -47,6 +47,10 @@ class MistralException(Error):
             '%d: %s' % (self.http_code, self.message))
 
 
+class DBException(MistralException):
+    http_code = 400
+
+
 class DataAccessException(MistralException):
     http_code = 400
 
@@ -74,7 +78,15 @@ class ActionRegistrationException(MistralException):
 
 
 class EngineException(MistralException):
-    pass
+    http_code = 500
+
+
+class WorkflowException(MistralException):
+    http_code = 400
+
+
+class WorkflowInputException(MistralException):
+    http_code = 400
 
 
 class ApplicationContextNotFoundException(MistralException):
@@ -82,6 +94,15 @@ class ApplicationContextNotFoundException(MistralException):
     message = "Application context not found"
 
 
+class DSLParsingException(MistralException):
+    http_code = 400
+
+
 class InvalidModelException(MistralException):
     http_code = 400
     message = "Wrong entity definition"
+
+
+class InvalidResultException(MistralException):
+    http_code = 400
+    message = "Unable to parse result"
\ No newline at end of file
