@@ -1,4 +1,5 @@
 # Copyright 2014 - Mirantis, Inc.
+# Copyright 2014 - StackStorm, Inc.
 #
 #    Licensed under the Apache License, Version 2.0 (the "License");
 #    you may not use this file except in compliance with the License.
@@ -22,14 +23,25 @@ from mistral.db.v2 import api as db_api
 from mistral import exceptions as exc
 from mistral import expressions as expr
 from mistral.openstack.common import log as logging
+from mistral.services import actions
+from mistral import utils
 from mistral.utils import inspect_utils as i_utils
 
 
 LOG = logging.getLogger(__name__)
 
+ACTIONS_PATH = '../resources/actions'
 _ACTION_CTX_PARAM = 'action_context'
 
 
+def register_standard_actions():
+    action_paths = utils.get_file_list(ACTIONS_PATH)
+
+    for action_path in action_paths:
+        action_definition = open(action_path).read()
+        actions.update_actions(action_definition, scope='public')
+
+
 def get_registered_actions(**kwargs):
     return db_api.get_actions(**kwargs)
 
@@ -42,7 +54,8 @@ def _register_action_in_db(name, action_class, attributes,
         'attributes': attributes,
         'description': description,
         'input': input_str,
-        'is_system': True
+        'is_system': True,
+        'scope': 'public'
     }
 
     try:
@@ -60,27 +73,27 @@ def _clear_system_action_db():
 def sync_db():
     _clear_system_action_db()
     register_action_classes()
+    register_standard_actions()
 
 
 def _register_dynamic_action_classes():
     for generator in generator_factory.all_generators():
-        action_classes = generator.create_action_classes()
+        actions = generator.create_actions()
 
         module = generator.base_action_class.__module__
         class_name = generator.base_action_class.__name__
 
         action_class_str = "%s.%s" % (module, class_name)
 
-        for action_name, action in action_classes.items():
-            full_action_name =\
-                "%s.%s" % (generator.action_namespace, action_name)
-
-            attrs = i_utils.get_public_fields(action)
+        for action in actions:
+            attrs = i_utils.get_public_fields(action['class'])
 
             _register_action_in_db(
-                full_action_name,
+                action['name'],
                 action_class_str,
-                attrs
+                attrs,
+                action['description'],
+                action['arg_list']
             )
 
 
@@ -123,24 +136,21 @@ def get_action_class(action_full_name):
                                                      action_db.attributes)
 
 
-def _get_action_context(db_task, openstack_context):
-    result = {
-        'workbook_name': db_task['workbook_name'],
-        'execution_id': db_task['execution_id'],
-        'task_id': db_task['id'],
-        'task_name': db_task['name'],
-        'task_tags': db_task['tags'],
+def get_action_context(task_db):
+    return {
+        _ACTION_CTX_PARAM: {
+            'workflow_name': task_db.execution.wf_name,
+            'execution_id': task_db.execution_id,
+            'task_id': task_db.id,
+            'task_name': task_db.name,
+            'task_tags': task_db.tags
+        }
     }
 
-    if openstack_context:
-        result.update({'openstack': openstack_context})
 
-    return result
-
-
-def _has_action_context_param(action_cls):
+def has_action_context(action, attributes):
+    action_cls = action_factory.construct_action_class(action, attributes)
     arg_spec = inspect.getargspec(action_cls.__init__)
-
     return _ACTION_CTX_PARAM in arg_spec.args
 
 
