@@ -17,59 +17,81 @@ from oslo.config import cfg
 from mistral import context
 from mistral.db.v2 import api as db_api
 from mistral.services import trusts
+from mistral import utils
 from mistral.workbook import parser as spec_parser
 
 
-def create_workflows(definition):
+WORKFLOWS_PATH = '../resources/workflows'
+
+
+def register_standard_workflows():
+    workflow_paths = utils.get_file_list(WORKFLOWS_PATH)
+
+    for wf_path in workflow_paths:
+        workflow_definition = open(wf_path).read()
+        update_workflows(workflow_definition, scope='public')
+
+
+def sync_db():
+    register_standard_workflows()
+
+
+def create_workflows(definition, scope='private'):
     wf_list_spec = spec_parser.get_workflow_list_spec_from_yaml(definition)
 
     db_wfs = []
 
     with db_api.transaction():
         for wf_spec in wf_list_spec.get_workflows():
-            db_wfs.append(create_workflow(wf_spec, definition))
+            db_wfs.append(_create_workflow(wf_spec, definition, scope))
 
     return db_wfs
 
 
-def update_workflows(definition):
+def update_workflows(definition, scope='private'):
     wf_list_spec = spec_parser.get_workflow_list_spec_from_yaml(definition)
 
     db_wfs = []
 
     with db_api.transaction():
         for wf_spec in wf_list_spec.get_workflows():
-            db_wfs.append(create_or_update_workflow(wf_spec, definition))
+            db_wfs.append(_create_or_update_workflow(
+                wf_spec,
+                definition,
+                scope
+            ))
 
     return db_wfs
 
 
-def create_workflow(wf_spec, definition):
+def _get_workflow_values(wf_spec, definition, scope):
     values = {
         'name': wf_spec.get_name(),
+        'tags': wf_spec.get_tags(),
         'definition': definition,
-        'spec': wf_spec.to_dict()
+        'spec': wf_spec.to_dict(),
+        'scope': scope
     }
 
-    _add_security_info(values)
+    _add_security_info(values, scope)
 
-    return db_api.create_workflow(values)
+    return values
 
 
-def create_or_update_workflow(wf_spec, definition):
-    values = {
-        'name': wf_spec.get_name(),
-        'definition': definition,
-        'spec': wf_spec.to_dict()
-    }
+def _create_workflow(wf_spec, definition, scope):
+    return db_api.create_workflow(
+        _get_workflow_values(wf_spec, definition, scope)
+    )
 
-    _add_security_info(values)
+
+def _create_or_update_workflow(wf_spec, definition, scope):
+    values = _get_workflow_values(wf_spec, definition, scope)
 
     return db_api.create_or_update_workflow(values['name'], values)
 
 
-def _add_security_info(values):
-    if cfg.CONF.pecan.auth_enable:
+def _add_security_info(values, scope):
+    if cfg.CONF.pecan.auth_enable and scope == 'private':
         values.update({
             'trust_id': trusts.create_trust().id,
             'project_id': context.ctx().project_id
