@@ -29,6 +29,7 @@ version: '2.0'
 
 my_action:
   description: My super cool action.
+  tags: ['test', 'v2']
   base: std.echo
   base-input:
     output: "{$.str1}{$.str2}"
@@ -47,7 +48,9 @@ std.echo:
 ACTION = {
     'id': '123',
     'name': 'my_action',
+    'is_system': False,
     'description': 'My super cool action.',
+    'tags': ['test', 'v2'],
     'definition': ACTION_DEFINITION
 }
 
