@@ -19,8 +19,6 @@ from mistral import utils
 from mistral.workbook import base
 from mistral.workbook.v2 import task_policies
 
-# TODO(rakhmerov): In progress.
-
 
 class TaskSpec(base.BaseSpec):
     # See http://json-schema.org
@@ -33,8 +31,10 @@ class TaskSpec(base.BaseSpec):
             "action": {"type": ["string", "null"]},
             "workflow": {"type": ["string", "null"]},
             "input": {"type": ["object", "null"]},
+            "for-each": {"type": ["object", "null"]},
             "publish": {"type": ["object", "null"]},
             "policies": {"type": ["object", "null"]},
+            "targets": {"type": ["array", "null"]},
             "requires": {"type": ["string", "array", "null"]},
             "on-complete": {"type": ["array", "null"]},
             "on-success": {"type": ["array", "null"]},
@@ -54,16 +54,19 @@ class TaskSpec(base.BaseSpec):
         self._action = data.get('action')
         self._workflow = data.get('workflow')
         self._input = data.get('input', {})
+        self._for_each = data.get('for-each', {})
         self._publish = data.get('publish', {})
         self._policies = self._spec_property(
             'policies',
             task_policies.TaskPoliciesSpec
         )
+        self._targets = data.get('targets', [])
         self._requires = data.get('requires', [])
         self._on_complete = self._as_list_of_tuples('on-complete')
         self._on_success = self._as_list_of_tuples('on-success')
         self._on_error = self._as_list_of_tuples('on-error')
 
+        self._process_for_each()
         self._process_action_and_workflow()
 
     def _process_action_and_workflow(self):
@@ -87,6 +90,14 @@ class TaskSpec(base.BaseSpec):
 
         utils.merge_dicts(self._input, params)
 
+    def _process_for_each(self):
+        if self._for_each:
+            for key, value in self._for_each.items():
+                if not isinstance(value, (list, six.string_types)):
+                    msg = ("Items of task property 'for-each' can only be "
+                           "a list or an expression string: %s" % self._data)
+                    raise exc.InvalidModelException(msg)
+
     def get_name(self):
         return self._name
 
@@ -102,9 +113,15 @@ class TaskSpec(base.BaseSpec):
     def get_input(self):
         return self._input
 
+    def get_for_each(self):
+        return self._for_each
+
     def get_policies(self):
         return self._policies
 
+    def get_targets(self):
+        return self._targets
+
     def get_publish(self):
         return self._publish
 
