@@ -14,6 +14,8 @@
 
 import abc
 
+from oslo.config import cfg
+
 from mistral import exceptions as exc
 from mistral.openstack.common import log as logging
 from mistral import utils
@@ -22,6 +24,7 @@ from mistral.workflow import data_flow
 from mistral.workflow import states
 
 LOG = logging.getLogger(__name__)
+WF_TRACE = logging.getLogger(cfg.CONF.workflow_trace_log_name)
 
 
 class WorkflowHandler(object):
@@ -68,21 +71,32 @@ class WorkflowHandler(object):
         if states.is_finished(task_db.state):
             return []
 
+        wf_trace_msg = "Task '%s' [%s -> " % (task_db.name, task_db.state)
+
         task_db.state = \
             states.ERROR if raw_result.is_error() else states.SUCCESS
         task_spec = self.wf_spec.get_tasks()[task_db.name]
 
+        wf_trace_msg += "%s" % task_db.state
+        if task_db.state == states.ERROR:
+            wf_trace_msg += ", error = %s]" % utils.cut(raw_result.error)
+            WF_TRACE.info(wf_trace_msg)
+        else:
+            wf_trace_msg += ", result = %s]" % utils.cut(raw_result.data)
+
+        WF_TRACE.info(wf_trace_msg)
+
         task_db.output =\
             data_flow.evaluate_task_output(task_spec, raw_result)
 
-        if task_db.state == states.ERROR and not task_spec.get_on_error():
+        commands = self._find_next_commands(task_db)
+
+        if task_db.state == states.ERROR and not commands:
             if not self.is_paused_or_finished():
                 self._set_execution_state(states.ERROR)
 
             return []
 
-        commands = self._find_next_commands(task_db)
-
         if len(commands) == 0:
             # If there are no running tasks at this point we can conclude that
             # the workflow has finished.
@@ -92,11 +106,6 @@ class WorkflowHandler(object):
 
                 task_out_ctx = data_flow.evaluate_outbound_context(task_db)
 
-                self.exec_db.context = utils.merge_dicts(
-                    self.exec_db.context,
-                    task_out_ctx
-                )
-
                 self.exec_db.output = data_flow.evaluate_workflow_output(
                     self.wf_spec,
                     task_out_ctx
